/***************************************************************************
 *   Copyright (C) 2003 by Hideki Ikemoto                                  *
 *   ikemo@wakaba.jp                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/

#include <cppunit/ui/text/TestRunner.h>
#include <cppunit/TextTestResult.h>

#include "k2ch_articlefiletest.h"
#include "urlconverttest.h"
#include "commenttest.h"
#include "threadtest.h"
#include "boardtest.h"
#include "misctest.h"
#include "favoritethreadstest.h"

int main( int argc, char* argv[] )
{
  CppUnit::TextUi::TestRunner runner;

  runner.addTest( K2chArticleFileTest::suite() );
  runner.addTest( URLConvertTest::suite() );
  runner.addTest( CommentTest::suite() );
  runner.addTest( ThreadTest::suite() );
  runner.addTest( BoardTest::suite() );
  runner.addTest( MiscTest::suite() );
  runner.addTest( FavoriteThreadsTest::suite() );
  runner.run( "" );
  return 0;
}
